package com.qmth.themis.business.templete.impl;

import cn.hutool.core.date.DateUtil;
import com.qmth.themis.business.constant.SystemConstant;
import com.qmth.themis.business.templete.TaskSyncCommon;
import com.qmth.themis.business.templete.TaskSyncTemplete;
import com.qmth.themis.business.util.CloudMarkUtil;
import com.qmth.themis.common.contanst.Constants;
import com.qmth.themis.common.util.Result;
import com.qmth.themis.common.util.ResultUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.File;
import java.io.IOException;
import java.time.LocalDateTime;
import java.util.*;

/**
 * @Description: 同步云阅卷成绩任务
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2020/10/20
 */
@Service
public class TaskSyncMarkCloudTemplete implements TaskSyncTemplete {

    private final static Logger log = LoggerFactory.getLogger(TaskSyncMarkCloudTemplete.class);

    @Resource
    CloudMarkUtil cloudMarkUtil;

    /**
     * 同步模版
     *
     * @param map
     * @return
     */
    @Override
    public Result syncTask(Map<String, Object> map) throws IOException {
        log.info("开始同步云阅卷成绩数据");
        long start = System.currentTimeMillis();
        TaskSyncCommon taskSyncCommon = new TaskSyncCommon(map);
        taskSyncCommon.init();
        taskSyncCommon.setTxtList(new ArrayList());
        StringJoiner stringJoiner = null;
        try {
            taskSyncCommon.getTxtList()
                    .add(DateUtil.format(new Date(), Constants.DEFAULT_DATE_PATTERN) + "->开始准备同步云阅卷成绩数据");
            Long orgId = (Long) map.get(SystemConstant.ORG_ID);
            String examCode = (String) map.get(SystemConstant.EXAM_CODE);

            boolean oss = (boolean) taskSyncCommon.getOssEnv().get(SystemConstant.OSS);
            stringJoiner = new StringJoiner("");
            if (!oss) {
                stringJoiner.add(SystemConstant.FILES_DIR).add(File.separator);
            }
            LocalDateTime nowTime = LocalDateTime.now();
            stringJoiner.add(String.valueOf(nowTime.getYear())).add(File.separator)
                    .add(String.format("%02d", nowTime.getMonthValue())).add(File.separator)
                    .add(String.format("%02d", nowTime.getDayOfMonth()));
            List<Map> finalList = cloudMarkUtil.callStudentScore(orgId, null, examCode);
            long end = System.currentTimeMillis();
            log.info("同步云阅卷成绩数据结束,============耗时============:{}秒", (end - start) / 1000);
        } catch (Exception e) {
            log.error("同步云阅卷成绩数据报错", e);
            taskSyncCommon.exception(e, taskSyncCommon.getTxtList());
        } finally {
            //这里写入txt文件
            taskSyncCommon.writeSyncResultTxt(stringJoiner.toString(), taskSyncCommon.getTxtList().toString());
        }
        return ResultUtil.ok(true);
    }
}